﻿using System;
using Ozeki.Network;
using Ozeki.VoIP;

namespace PBX_Authentication
{
    class MainClass
    {
        private static void Main(string[] args)
        {
            var myPBX = new MyPBX(NetworkAddressHelper.GetLocalIP().ToString(), 20000, 30000);
            myPBX.Start();

            Console.ReadLine();
            myPBX.Stop();
        }
    }


    class MyPBX : PBXBase
    {
        string localAddress;

        public MyPBX(string localAddress, int minPortRange, int maxPortRange)
            : base(minPortRange, maxPortRange)
        {
            this.localAddress = localAddress;
            Console.WriteLine("PBX starting...");
            Console.WriteLine("Local address: " + localAddress);
        }

        protected override void OnStart()
        {
            Console.WriteLine("PBX started.");
            SetListenPort(localAddress, 5060, TransportType.Udp);

            Console.WriteLine("Listened port: 5060(UDP)");
            base.OnStart();
        }

        protected override RegisterResult OnRegisterReceived(ISIPExtension extension, SIPAddress from, int expires)
        {
            Console.WriteLine("Register received from: " + extension.ExtensionID);
            return base.OnRegisterReceived(extension, from, expires);
        }

        protected override void OnUnregisterReceived(ISIPExtension extension)
        {
            Console.WriteLine("Unregister received from: " + extension.ExtensionID);
            base.OnUnregisterReceived(extension);
        }

        protected override void OnCallRequestReceived(ISessionCall call)
        {
            Console.WriteLine("Call request received. Caller: " + call.DialInfo.CallerID + " callee: " + call.DialInfo.Dialed);
            base.OnCallRequestReceived(call);
        }

        protected override AuthenticationResult OnAuthenticationRequest(ISIPExtension extension, RequestAuthenticationInfo requestAuthInfo)
        {
            if (extension.ExtensionID == "1001")
            {
                Console.WriteLine("Authentication accepted.");
                return new AuthenticationResult(true);
            }
            else
            {
                Console.WriteLine("Authentication denied!");
                return new AuthenticationResult(false, "Not allowed username.");  // second parameter is optional
            }
        }

    }
}
